Enum beaker::NetworkVariant
source · pub enum NetworkVariant {
Local,
Shared,
}Variants
Local
Beaker’s state of the network will not be shared with collaborator via vcs
Beaker’s state of the network will be shared with collaborator via vcs